\name{m3}
\alias{m3}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Computes a 3-state parametric Markov model by likelihood maximization
}
\description{
The 3-state Markov model includes an initial state (X=1), a transient state (X=2) and an absorbing state (X=3). Usually, X=1 corresponds to disease-free or remission, X=2 to relapse, and X=3 to death. In this illness-death model, the possible transitions are: 1->2, 1->3 and 2->3.
}
\usage{
m3(t1, t2, sequence, dist, cuts.12=NULL, cuts.13=NULL, cuts.23=NULL, 
ini.base.12=NULL, ini.base.13=NULL, ini.base.23=NULL, cov.12=NULL, 
init.cov.12=NULL, names.12=NULL, cov.13=NULL, init.cov.13=NULL, 
names.13=NULL, cov.23=NULL, init.cov.23=NULL, names.23=NULL, 
conf.int=TRUE, silent=TRUE, precision=10^(-6), maxiter=10^4)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{t1}{a numeric vector with the observed times in days from baseline to the first transition (X=2 or X=3) or to the right-censoring in X=1.}
  \item{t2}{a numeric vector with the observed times in days from baseline to the second transition or to the right censoring in X=2. \code{NA} for individuals right-censored in X=1 or individuals who directly transited from X=1 to X=3.}
  \item{sequence}{a numeric vector with the sequence of observed states. Four possible values are allowed: 1 (individual right-censored in X=1), 12 (individual right-censored in X=2), 13 (individual who directly transited from X=1 to X=3), 123 (individual who transited from X=1 to X=3 through X=2).}
  \item{dist}{a character vector with three arguments describing respectively the distributions of duration time for transitions 1->2, 1->3 and 2->3. Arguments allowed are \code{"E"} for Exponential distribution, \code{"PE"} for the piecewise exponential distribution, \code{"W"} for Weibull distribution or \code{"WG"} for Generalized Weibull distribution.}
  \item{cuts.12}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=1 to X=2. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.13}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=1 to X=3. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{cuts.23}{a numeric vector indicating the timepoints in days for the piecewise exponential distribution related to the time from X=2 to X=3. Only internal timepoints are allowed: timepoints cannot be \code{0} or \code{Inf}. Default is \code{NULL} which means that the distribution is not piecewise. Piecewise model is only allowed for exponential distribution.}
  \item{ini.base.12}{a numeric vector of initial logarithm values for parameters of distribution from X=1 to X=2. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.13}{a numeric vector of initial logarithm values for parameters of distribution from X=1 to X=3. Default initial value is 1 for all parameters. See \code{details} for more details.}
  \item{ini.base.23}{a numeric vector of initial logarithm values for parameters of distribution from X=2 to X=3. Default initial value is 1 for all parameters. See \code{details} for more details.}
 \item{cov.12}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=1 to X=2.}
 \item{init.cov.12}{a numeric vector of initial values for regression coefficients associated to \code{cov.12}. Default initial value is 0 for all parameters.}
 \item{names.12}{a character vector with name of explicative variables associated to \code{cov.12} (optional).}
 \item{cov.13}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=1 to X=3.}
 \item{init.cov.13}{a numeric vector of initial values for regression coefficients associated to \code{cov.13}. Default initial value is 0 for all parameters.}
 \item{names.13}{a character vector with name of explicative variables associated to \code{cov.13} (optional).}
 \item{cov.23}{a numeric matrix (or data.frame) with the explicative time-fixed variable(s) related to the time from X=2 to X=3.}
 \item{init.cov.23}{a numeric vector of initial values for regression coefficients associated to \code{cov.23}. Default initial value is 0 for all parameters.}
 \item{names.23}{a character vector with name of explicative variables associated to \code{cov.23} (optional).}
 \item{conf.int}{a logical value specifying if the pointwise confidence intervals for parameters and the variance-covariance matrix should be returned. Default is \code{TRUE}.}
 \item{silent}{a logical value specifying if the log-likelihood value should be returned at each iteration. Default is \code{TRUE}, which corresponds to silent mode (no display).}
 \item{precision}{a numeric positive value indicating the required precision for the log-likelihood maximization between each iteration. Default is \eqn{10^{-6}}.}
 \item{maxiter}{a numeric positive value indicating the maximum number of iterations for the log-likelihood maximization. Default is \eqn{10^{4}}.}
 }
\details{
Hazard functions available are:
\tabular{rl}{
\code{Exponential} distribution \tab \eqn{\lambda(t)=1/\sigma} \cr											
\code{Weibull} distribution \tab \eqn{\lambda(t)=\nu(\frac{1}{\sigma})^{\nu}t^{\nu-1}} \cr
\code{Generalized Weibull} distribution \tab \eqn{\lambda(t)=\frac{1}{\theta}\left(1+\left(\frac{t}{\sigma}\right)^{\nu}\right)^{\frac{1}{\theta}-1} \nu\left(\frac{1}{\sigma}\right)^{\nu} t^{\nu-1}}
}
with \eqn{\sigma}, \eqn{\nu},and \eqn{\theta>0}. The parameter \eqn{\sigma} varies for each interval when the distribution is piecewise Exponential. To avoid negative values, these parameters are exponentiated in the model. Therefore, the user must initialize logarithm values of parameters in \code{ini.base.12}, \code{ini.base.13} and \code{ini.base.23}. Moreover, the estimated values also correspond to the logarithms. Maximization of the log-likelihood function is performed using the algorithms of Nelder and Mead (\code{optim} function). 
}
\value{
\item{Table}{a data.frame containing the parameter estimations of the model (\code{Estimate}). When the option \code{conf.int=TRUE} is specified, this data.frame includes three additional columns: the Standard Errors of parameters (\code{Std.Error}), the value of the Wald statistic (\code{t.value}), and the p-value for the Wald test (\code{Pr(>|t|)}).}
\item{CovarianceMatrix}{a data.frame corresponding to variance-covariance matrix of the estimated model.}
\item{LogLik}{a numeric value corresponding to the log-likelihood of the estimated model.}
\item{AIC}{a numeric value corresponding to the Akaike Information Criterion of the estimated model.}
}
\references{
Huszti E, Abrahamowicz M, Alioum A, Binquet C, Quantin C. Relative survival multistate Markov model. Stat Med. 2012 Feb 10;31(3):269-86.}
\author{
Yohann Foucher <Yohann.Foucher@univ-nantes.fr> and

Florence Gillaizeau <Florence.Gillaizeau@univ-nantes.fr>
}

\examples{

# import the observed data
# (X=1 corresponds to initial state with a functioning graft, X=2 to acute rejection episode, 
# X=3 to return to dialysis, X=4 to death with a functioning graft)

data(dataDIVAT)

# A subgroup analysis to reduce the time needed for this example

dataDIVAT$id<-c(1:nrow(dataDIVAT))
set.seed(2)
dataDIVATsample<-dataDIVAT[dataDIVAT$id \%in\% sample(dataDIVAT$id, trunc(nrow(dataDIVAT)/10),
replace = FALSE),]

# To illustrate the use of a 3-state model, individuals with trajectory 13 and 123 are 
# censored at the time of transition into state X=3

dataDIVAT_3state<-dataDIVATsample
dataDIVAT_3state$trajectory[dataDIVAT_3state$trajectory==13]<-1
dataDIVAT_3state$trajectory[dataDIVAT_3state$trajectory==123]<-12
dataDIVAT_3state$trajectory[dataDIVAT_3state$trajectory==14]<-13
dataDIVAT_3state$trajectory[dataDIVAT_3state$trajectory==124]<-123

# 3-state parametric Markov model including one explicative variable ('z') 
# on all transitions

m3(t1=dataDIVAT_3state$time1,
  t2=dataDIVAT_3state$time2,
  sequence=dataDIVAT_3state$trajectory,
  dist=c("W","W","W"),
  cuts.12=NULL,
  cuts.13=NULL,
  cuts.23=NULL,
  ini.base.12=c(9.93,-1.00),
  ini.base.13=c(11.54,-0.20),
  ini.base.23=c(10.21,0.21),
  cov.12=dataDIVAT_3state$z,
  init.cov.12=c(-0.13),
  names.12=c("beta12_z") ,
  cov.13=dataDIVAT_3state$z,
  init.cov.13=c(1.61),
  names.13=c("beta13_z") ,
  cov.23=dataDIVAT_3state$z,
  init.cov.23=c(1.39),
  names.23=c("beta23_z"),
  conf.int=TRUE,
  silent=FALSE,
  precision=0.001,
  maxiter=1000)

}

\keyword{ Markov }
\keyword{ multistate }
\keyword{ illness-death }

